@@ -33,7 +33,7 @@ contains
 
 subroutine menu
   use filenames,        only:defaultsfile,limitsfile,fileprefix,set_filenames
-  use labels,           only:label,labelvec,iamvec,isurfdens,itoomre,ipdf,icolpixmap,is_coord
+  use labels,           only:label,labelvec,iamvec,isurfdens,itoomre,ipdf,icolpixmap,is_coord,ix
   use limits,           only:write_limits,lim2,lim,reset_lim2,lim2set
   use options_data,     only:submenu_data
   use settings_data,    only:ndim,numplot,ndataplots,nextra,ncalc,ivegotdata, &
@@ -64,7 +64,11 @@ subroutine menu
   irender = 0
   icontourplot = 0
   ivecplot = 0
-  ipickx = 1
+  if (ndim > 1 .and. ix(1) > 0) then
+     ipickx = ix(1)
+  else
+     ipickx = 1
+  endif
   ipicky = 1
 
   menuloop: do
@@ -195,7 +199,20 @@ subroutine menu
         !--if needed prompt for x axis selection
         !
         if (ipicky <= (numplot-nextra)) then
-           if (ipickx==0) ipickx = 1 ! do not allow zero as default
+           if (ipickx==0) then
+              if (ndim > 1 .and. ix(1) > 0) then
+                 ipickx = ix(1)
+              else
+                 ipickx = 1 ! do not allow zero as default
+              endif
+           endif
+           if (ipickx==ipicky) then ! do not allow x same as y by default
+              if (ipickx > 1) then
+                 ipickx = ipicky-1
+              else
+                 ipickx = ipicky+1
+              endif
+           endif
            call prompt(' (x axis) ',ipickx)
            !--go back to y prompt if out of range
            if (ipickx.gt.numplot .or. ipickx.le.0) cycle menuloop
@@ -210,27 +227,31 @@ subroutine menu
            !  to icoordsnew, or alternatively plot non-cartesian pixel shapes)
            ! -> also do not allow if transformations are applied
            !
-           if (is_coord(ipicky,ndim) .and. is_coord(ipickx,ndim) .and. iAllowRendering) then
-              call prompt('(render) (0=none)',irender,0,(numplot-nextra))
-              if (irender > 0 .and. iplotcont_nomulti .and. icolours /= 0) then
-                 if (double_rendering) then
-                    rprompt = '2nd render'
-                 else
-                    rprompt = 'contours'
-                 endif
-                 call prompt('('//trim(rprompt)//') (0=none)',icontourplot,0,(numplot-nextra))
-                 if (icontourplot==irender) then
-                    if (iadapt) then
-                       print "(a)",' limits for '//trim(rprompt)//' are adaptive'
+           if (is_coord(ipicky,ndim) .and. is_coord(ipickx,ndim)) then
+              if (iAllowRendering) then
+                 call prompt('(render) (0=none)',irender,0,(numplot-nextra))
+                 if (irender > 0 .and. iplotcont_nomulti .and. icolours /= 0) then
+                    if (double_rendering) then
+                       rprompt = '2nd render'
                     else
-                       if (.not.lim2set(icontourplot)) lim2(icontourplot,:) = lim(icontourplot,:)
-                       call prompt(' enter min for '//trim(rprompt)//':',lim2(icontourplot,1))
-                       call prompt(' enter max for '//trim(rprompt)//':',lim2(icontourplot,2))
-                       if (all(abs(lim2(icontourplot,:)-lim(icontourplot,:)) < tiny(lim))) then
-                          call reset_lim2(icontourplot)
+                       rprompt = 'contours'
+                    endif
+                    call prompt('('//trim(rprompt)//') (0=none)',icontourplot,0,(numplot-nextra))
+                    if (icontourplot==irender) then
+                       if (iadapt) then
+                          print "(a)",' limits for '//trim(rprompt)//' are adaptive'
+                       else
+                          if (.not.lim2set(icontourplot)) lim2(icontourplot,:) = lim(icontourplot,:)
+                          call prompt(' enter min for '//trim(rprompt)//':',lim2(icontourplot,1))
+                          call prompt(' enter max for '//trim(rprompt)//':',lim2(icontourplot,2))
+                          if (all(abs(lim2(icontourplot,:)-lim(icontourplot,:)) < tiny(lim))) then
+                             call reset_lim2(icontourplot)
+                          endif
                        endif
                     endif
                  endif
+              else
+                 irender = 0
               endif
               if (any(iamvec(1:numplot).ne.0)) then
                  ivecplottemp = -1
@@ -274,6 +295,9 @@ subroutine menu
         !--for multiplots, check that options are valid. If not, re-prompt for multiplot
         !  settings
         !
+            ipickx   = 0
+            irender  = 0
+            ivecplot = 0
             if (any(multiploty(1:nyplotmulti) <= 0) .or. &
                 any(multiploty(1:nyplotmulti) > numplot) .or. &
                 any(multiplotx(1:nyplotmulti) <= 0) .or. &
@@ -465,32 +489,33 @@ subroutine menu
       icoordplot = (is_coord(multiplotx(i),ndim) .and. is_coord(multiploty(i),ndim))
       if (icoordplot) anycoordplot = icoordplot
 
-      if (icoordplot .and.iAllowRendering) then
-         call prompt('(render) (0=none)',irendermulti(i),0,numplot-nextra)
-         if (irendermulti(i).gt.0 .and. iplotcont_nomulti .and. icolours.ne.0) then
-            if (double_rendering) then
-               rprompt = '2nd render'
-            else
-               rprompt = 'contours'
-            endif
-            call prompt('('//trim(rprompt)//') (0=none)',icontourmulti(i),0,numplot-nextra)
-            if (icontourmulti(i).eq.irendermulti(i)) then
-               if (iadapt) then
-                  print "(a)",' limits for '//trim(rprompt)//' are adaptive '
+      if (icoordplot) then
+         if (iAllowRendering) then
+            call prompt('(render) (0=none)',irendermulti(i),0,numplot-nextra)
+            if (irendermulti(i).gt.0 .and. iplotcont_nomulti .and. icolours.ne.0) then
+               if (double_rendering) then
+                  rprompt = '2nd render'
                else
-                  if (.not.lim2set(icontourmulti(i))) lim2(icontourmulti(i),:) = lim(icontourmulti(i),:)
-                  call prompt(' enter min for '//trim(rprompt)//':',lim2(icontourmulti(i),1))
-                  call prompt(' enter max for '//trim(rprompt)//':',lim2(icontourmulti(i),2))
-                  if (all(abs(lim2(icontourmulti(i),:)-lim(icontourmulti(i),:)) < tiny(lim))) then
-                     call reset_lim2(icontourmulti(i))
+                  rprompt = 'contours'
+               endif
+               call prompt('('//trim(rprompt)//') (0=none)',icontourmulti(i),0,numplot-nextra)
+               if (icontourmulti(i).eq.irendermulti(i)) then
+                  if (iadapt) then
+                     print "(a)",' limits for '//trim(rprompt)//' are adaptive '
+                  else
+                     if (.not.lim2set(icontourmulti(i))) lim2(icontourmulti(i),:) = lim(icontourmulti(i),:)
+                     call prompt(' enter min for '//trim(rprompt)//':',lim2(icontourmulti(i),1))
+                     call prompt(' enter max for '//trim(rprompt)//':',lim2(icontourmulti(i),2))
+                     if (all(abs(lim2(icontourmulti(i),:)-lim(icontourmulti(i),:)) < tiny(lim))) then
+                        call reset_lim2(icontourmulti(i))
+                     endif
                   endif
                endif
+            else
+               icontourmulti(i) = 0
             endif
-         else
-            icontourmulti(i) = 0
+            !iplotcontmulti(i) = iplotcont_nomulti
          endif
-         !iplotcontmulti(i) = iplotcont_nomulti
-
          if (any(iamvec(1:numplot).gt.0)) then
             ivecplottemp = -1
             ierr = 1
@@ -631,12 +656,13 @@ logical function allowrendering(iplotx,iploty)
 !
  if ((ih.gt.0 .and. ih.le.ndataplots) &
     .and.(irho.gt.0 .and. irho.le.ndataplots) &
-    !.and.(icoords.eq.icoordsnew .or. icolour_particles) &
-    .and.((itransx.eq.0 .and. itransy.eq.0).or.icolour_particles)) then
+    !.and.(icoords.eq.icoordsnew) &
+    .and.(itransx.eq.0 .and. itransy.eq.0)) then
 
     allowrendering = .true.
  else
     allowrendering = .false.
+    if (icolour_particles) allowrendering = .true.
  endif
 
 end function allowrendering
@@ -778,12 +804,16 @@ subroutine print_header
  integer, parameter :: c(49) = (/32,120,111,120,111,120,111,120,111,32,77,101,114,114,121,32,&
                       67,104,114,105,115,116,109,97,115,32,102,114,111,109,32,115,&
                       112,108,97,115,104,33,32,120,111,120,111,120,111,120,111,120,111/)
-
+ integer, parameter :: d(49) = (/32,79,111,79,111,79,111,79,32,83,80,76,65,83,72,32,119, &
+                      105,115,104,101,115,32,121,111,117,32,97,32,118,101,114,121,32,104,&
+                      97,112,112,121,32,33,32,79,111,79,111,79,111,79/)
  call date_and_time(values=v)
  if (v(2)==m(1)/4 .and. v(3)==v(2)-2) then
     print "(/,48(a))",(achar(m(i)),i=1,48)
  elseif (v(2)==(m(1)-20) .and. v(3)>20) then
     print "(/,49(a))",(achar(c(i)),i=1,49)
+ elseif (v(2)==nint(0.6) .and. v(3)==d(2)/79) then
+    print "(/,40(a),i4,9(a))",(achar(d(i)),i=1,40),v(1),(achar(d(i)),i=41,49)
  else
     print "(/a)",' You may choose from a delectable sample of plots'
  endif
