@@ -15,7 +15,7 @@
 !  a) You must cause the modified files to carry prominent notices
 !     stating that you changed the files and the date of any change.
 !
-!  Copyright (C) 2005-2013 Daniel Price. All rights reserved.
+!  Copyright (C) 2005-2014 Daniel Price. All rights reserved.
 !  Contact: daniel.price@monash.edu
 !
 !-----------------------------------------------------------------
@@ -140,9 +140,10 @@ subroutine submenu_page(ichoose)
  use plotlib,     only:plotlib_supports_alpha,plotlib_maxlinecolour,plotlib_maxlinestyle,plotlib_is_pgplot
  implicit none
  integer, intent(in) :: ichoose
- integer             :: iaction,i,iunitsprev
+ integer             :: iaction,i,iunitsprev,ierr
  real                :: papersizey
  character(len=15)   :: paperfmtstr
+ character(len=3)    :: string
 
  iaction = ichoose
  
@@ -199,8 +200,9 @@ subroutine submenu_page(ichoose)
         call prompt('Use different markers/line style for each step? ',iChangeStyles)
         if (iChangeStyles) then
            call prompt('How often to change line style (1=every step, 2=every 2nd step etc.)',modlinestyle,1)
-           call prompt('Enter max number of line styles to cycle through before repeating (5=plot lib max)',&
-                        maxlinestyle,1,plotlib_maxlinestyle)
+           write(string,"(i3)",iostat=ierr) plotlib_maxlinestyle
+           call prompt('Enter max number of line styles to cycle through before repeating ('// &
+                       trim(adjustl(string))//'=plot lib max)',maxlinestyle,1,plotlib_maxlinestyle)
         endif
 
         if (iColourEachStep .or. iChangeStyles) then
@@ -247,15 +249,17 @@ subroutine submenu_page(ichoose)
         print*,' 7) 800  x 600  pixels'
         print*,' 8) 640  x 360  pixels (360p)'
         print*,' 9) 1280 x 720  pixels (720p)'
-        print*,'10) 1920 x 1080 pixels (1080p)'
+        print*,'10) 1920 x 1080 pixels (1080p/Full HD)'
         print*,'11) 1024 x 768  pixels'
         print*,'12) 1440 x 900  pixels'
         print*,'13) 2560 x 1440 pixels'
         print*,'14) 2560 x 1600 pixels'
         print*,'15) 3840 x 2160 pixels (4KTV/Ultra HD)'
-        print*,'16) 27320 x 3072 pixels (CAVE-2)'
-        print*,'17) Custom size '
-        call prompt(' Enter option for paper size ',ipapersize,0,17)
+        print*,'16) 4096 x 2160 pixels (Cinema 4K)'
+        print*,'17) 5120 x 2880 pixels (5K)'
+        print*,'18) 27320 x 3072 pixels (CAVE-2)'
+        print*,'19) Custom size '
+        call prompt(' Enter option for paper size ',ipapersize,0,19)
      endif
      
      select case(ipapersize)
@@ -300,7 +304,7 @@ subroutine submenu_page(ichoose)
            papersizey = 600.
            aspectratio = papersizey/papersizex
         endif
-     case(8:16)
+     case(8:18)
         if (plotlib_is_pgplot) then
            ipapersizeunits = 1
            papersizex  = 0.  ! use PGPLOT default
@@ -333,12 +337,18 @@ subroutine submenu_page(ichoose)
               papersizex = 3840.
               papersizey = 2160.
            case(16)
+              papersizex = 4096.
+              papersizey = 2160.
+           case(17)
+              papersizex = 5120.
+              papersizey = 2880.
+           case(18)
               papersizex = 27320.
               papersizey = 3072.
            end select
            aspectratio = papersizey/papersizex
         endif
-     case(17)
+     case(19)
         if (plotlib_is_pgplot) then
            ipapersizeunits = 1
            papersizex  = 0.  ! use PGPLOT default
